.. _developer-docs:

=======================
Developer documentation
=======================

The developer documentation contains guidlines for how to 
stay up-to-date on Corrfunc development, submit bug reports and 
contribute to the Corrfunc code base. 


.. toctree::
   :maxdepth: 1

   citing_corrfunc
   contributors
   bug_reports
   staying_up_to_date
   contributing


